@@ -9,7 +9,7 @@ class TornadoHandler(tornado.web.RequestHandler):
         self.checker = checker
 
     def get(self, *args, **kwargs):
-        message, status_code, headers = self.checker.run()
+        message, status_code, headers = self.checker.run(*args, **kwargs)
         self.set_status(status_code)
         [self.set_header(k, v) for k, v in headers.items()]
         self.write(message)
